==> uikit-3.17.8.jar: META-INF/resources/webjars/uikit/3.17.8/src/js/core/form-custom.js <==
import { $, $$, closest, isInput, matches, parent, selInput } from 'uikit-util';
import Class from '../mixin/class';

export default {
    mixins: [Class],

    args: 'target',

    props: {
        target: Boolean,
    },

    data: {
        target: false,
    },

    computed: {
        input: (_, $el) => $(selInput, $el),

        state() {
            return this.input.nextElementSibling;
        },

        target({ target }, $el) {
            return (
                target &&
                ((target === true && parent(this.input) === $el && this.input.nextElementSibling) ||
                    $(target, $el))
            );
        },
    },

    update() {
        const { target, input } = this;

        if (!target) {
            return;
        }

        let option;
        const prop = isInput(target) ? 'value' : 'textContent';
        const prev = target[prop];
        const value = input.files?.[0]
            ? input.files[0].name
            : matches(input, 'select') &&
              (option = $$('option', input).filter((el) => el.selected)[0]) // eslint-disable-line prefer-destructuring
            ? option.textContent
            : input.value;

        if (prev !== value) {
            target[prop] = value;
        }
    },

    events: [
        {
            name: 'change',

            handler() {
                this.$emit();
            },
        },

        {
            name: 'reset',

            el() {
                return closest(this.$el, 'form');
            },

            handler() {
                this.$emit();
            },
        },
    ],
};

==> uikit-3.18.2.jar: META-INF/resources/webjars/uikit/3.18.2/src/js/core/form-custom.js <==
import { $, $$, isInput, matches, parent, selInput } from 'uikit-util';
import Class from '../mixin/class';

export default {
    mixins: [Class],

    args: 'target',

    props: {
        target: Boolean,
    },

    data: {
        target: false,
    },

    computed: {
        input: (_, $el) => $(selInput, $el),

        state() {
            return this.input.nextElementSibling;
        },

        target({ target }, $el) {
            return (
                target &&
                ((target === true && parent(this.input) === $el && this.input.nextElementSibling) ||
                    $(target, $el))
            );
        },
    },

    update() {
        const { target, input } = this;

        if (!target) {
            return;
        }

        let option;
        const prop = isInput(target) ? 'value' : 'textContent';
        const prev = target[prop];
        const value = input.files?.[0]
            ? input.files[0].name
            : matches(input, 'select') &&
                (option = $$('option', input).filter((el) => el.selected)[0]) // eslint-disable-line prefer-destructuring
              ? option.textContent
              : input.value;

        if (prev !== value) {
            target[prop] = value;
        }
    },

    events: [
        {
            name: 'change',

            handler() {
                this.$emit();
            },
        },

        {
            name: 'reset',

            el() {
                return this.$el.closest('form');
            },

            handler() {
                this.$emit();
            },
        },
    ],
};
